Behaviour defining the transport interface for Playwright communication.
Transports abstract how Playwriter communicates with Playwright:
Playwriter.Transport.Local- Uses playwright_ex with Erlang PortsPlaywriter.Transport.Remote- Uses WebSocket to remote Playwright server
Summary
Callbacks
Click an element
Close a browser
Close a context
Close a page
Get page content
Fill an input
Navigate to a URL
Check if transport is healthy
Launch a browser instance
Create a new browser context
Create a new page in a context
Take a screenshot
Send a message to Playwright and wait for response
Start the transport connection
Stop the transport
Types
Callbacks
Click an element
Close a browser
Close a context
Close a page
Get page content
Fill an input
Navigate to a URL
Check if transport is healthy
@callback launch_browser(transport(), browser_type(), keyword()) :: {:ok, guid()} | {:error, term()}
Launch a browser instance
Create a new browser context
Create a new page in a context
Take a screenshot
Send a message to Playwright and wait for response
Start the transport connection
@callback stop(transport()) :: :ok
Stop the transport